==> pegasus-support-1.6.30-sources.jar: com/thebeastshop/support/vo/cart/CartBenefitVO.java <==
package com.thebeastshop.support.vo.cart;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * Created by feilong.gao on 2017/2/22.
 */
public class CartBenefitVO implements Serializable {

	/**
	 *
	 */
	private static final long serialVersionUID = 7949689391932894329L;

	/**
	 * 权益id
	 */
	private String id;
	/**
	 * 权益兑换开始时间
	 */
	private Date cashStartTime;

	/**
	 * 是否有门槛
	 */
	private Boolean isThreshold = true;
	/**
	 * 权益兑换结束时间
	 */
	private Date cashEndTime;

	/**
	 * 抵扣金额
	 */
	private BigDecimal deductionPrice;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public Date getCashStartTime() {
		return cashStartTime;
	}

	public void setCashStartTime(Date cashStartTime) {
		this.cashStartTime = cashStartTime;
	}

	public Date getCashEndTime() {
		return cashEndTime;
	}

	public void setCashEndTime(Date cashEndTime) {
		this.cashEndTime = cashEndTime;
	}

	public BigDecimal getDeductionPrice() {
		return deductionPrice;
	}

	public void setDeductionPrice(BigDecimal deductionPrice) {
		this.deductionPrice = deductionPrice;
	}

	public Boolean getIsThreshold() {
		return isThreshold;
	}

	public void setIsThreshold(Boolean isThreshold) {
		this.isThreshold = isThreshold;
	}

	@Override
	public String toString() {
		final StringBuilder sb = new StringBuilder("CartBenefitVO{");
		sb.append("id='").append(id).append('\'');
		sb.append(", cashStartTime=").append(cashStartTime);
		sb.append(", cashEndTime=").append(cashEndTime);
		sb.append(", isThreshold=").append(isThreshold);
		sb.append('}');
		return sb.toString();
	}
}

==> pegasus-support-1.9.3-sources.jar: com/thebeastshop/support/vo/cart/CartBenefitVO.java <==
package com.thebeastshop.support.vo.cart;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * Created by feilong.gao on 2017/2/22.
 */
public class CartBenefitVO implements Serializable {

	/**
	 *
	 */
	private static final long serialVersionUID = 7949689391932894329L;

	/**
	 * 权益id
	 */
	private String id;
	/**
	 * 权益兑换开始时间
	 */
	private Date cashStartTime;

	/**
	 * 是否有门槛
	 */
	private Boolean isThreshold = true;

	/**
	 * 门槛金额
	 */
	private BigDecimal thresholdPrice;
	/**
	 * 权益兑换结束时间
	 */
	private Date cashEndTime;

	/**
	 * 抵扣金额
	 */
	private BigDecimal deductionPrice;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public Date getCashStartTime() {
		return cashStartTime;
	}

	public void setCashStartTime(Date cashStartTime) {
		this.cashStartTime = cashStartTime;
	}

	public Date getCashEndTime() {
		return cashEndTime;
	}

	public void setCashEndTime(Date cashEndTime) {
		this.cashEndTime = cashEndTime;
	}

	public BigDecimal getDeductionPrice() {
		return deductionPrice;
	}

	public void setDeductionPrice(BigDecimal deductionPrice) {
		this.deductionPrice = deductionPrice;
	}

	public Boolean getIsThreshold() {
		return isThreshold;
	}

	public void setIsThreshold(Boolean isThreshold) {
		this.isThreshold = isThreshold;
	}

	public BigDecimal getThresholdPrice() {
		return thresholdPrice;
	}

	public void setThresholdPrice(BigDecimal thresholdPrice) {
		this.thresholdPrice = thresholdPrice;
	}

	@Override
	public String toString() {
		return "CartBenefitVO{" +
				"id='" + id + '\'' +
				", cashStartTime=" + cashStartTime +
				", isThreshold=" + isThreshold +
				", thresholdPrice=" + thresholdPrice +
				", cashEndTime=" + cashEndTime +
				", deductionPrice=" + deductionPrice +
				'}';
	}
}
